
module Ues::Core::Search
  # This command checks the existence of an artifact or an aggregated object in the system. It doesn't check any business rules, so it
  # never throws an application exception (system exceptions like web services connection problems can still occur). If the current user
  # has an access to the territory specified in objectUri, the command returns true if there is an aggregated object or an artifact with
  # UESURI objectUri. If false is returned in this case, it is safe to assume the UESURI is not used and it is free to use (Bear in mind
  # this applies only in the moment of the command call. ). If the current user doesn't have an access to the territory or the territory
  # doesn't exist, the command always returns false.
  #
  # <tt><b>since</b></tt> UES6-06
  # <tt><b>param</b></tt> objectUri UESURI of an artifact or an aggregated object
  # <tt><b>return</b></tt> The existence of an artifact or an aggregated object in the system.
  private
  def exists(objectUri)
    UESSearch.exists(objectUri)
  end
end
