#--
# This code is automatically generated, do not modify the content !!!
#++
class Ues::Core::Security::UESPermission
  private_class_method :new


# The command grants permission for the specified artifact and its aggregated objects. The permission must be specified for concrete
# authority (role, group or implicit group). A permission mask (defined on artifact's meta artifact - see
# UESMetaPermission#getMaskList) or own settings data (see UESPermissionGrant#data) can be used for permission settings.
# 
# <tt><b>param</b></tt> entityUri UESURI of the entity for that the permission is granted
# 
# <tt><b>param</b></tt> permission DTO containing attributes of the permission
# 
# <tt><b>throws</b></tt> UESPermissionRTException
# 
# <tt><b>since</b></tt> UES8-03
  def self.grant(entityUri, permission = nil)
    entityUri = Ues::Core::Commons::Uri::UESURI.new(entityUri).to_java
    permission = Ues::Core::Security::Authz::UESPermissionGrant.new(permission).to_java
    _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.security.UESPermission.java_class)
    _r = _s.grant(entityUri, permission)
    
    return _r
  end

# Checks whether the logged user is authorized to the specific use case over the specific entity. If the user is not authorized to run the specified use case, the authorization exception (cz.ues.platform.security.authz.UESAuthorizationServiceRTException.E05401#M08) is thrown.
# 
# Note that authorization entities may differ from main entities of specific uuCommands. For example the uuCommand UU::OS::Property.create uses an artifact as the main entity, but it is authorized over the property group where the property is to be created.
# 
# <tt><b>param</b></tt> authorityUri UESURI of the entity (artifact, object) over which the logged user will be authorized. Never null.
# 
# <tt><b>param</b></tt> useCaseCode Code of the specific use case according to will be logged user authorized.
# 
# <tt><b>throws</b></tt> UESPermissionRTException
  def self.authorize(entityUri, permission = nil)
    entityUri = Ues::Core::Commons::Uri::UESURI.new(entityUri).to_java
    permission = Ues::Core::Security::Authz::UESPermissionAuthorize.new(permission).to_java
    _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.security.UESPermission.java_class)
    _r = _s.authorize(entityUri, permission)
    if (_r != nil) then _r = Ues::Core::Security::Authz::UESPermissionAuthorizeResult.new(_r) end
    return _r
  end

# The command revokes permissions for the specified artifact and its aggregated objects. The permissions must be specified for a concrete
# authority (role, group or implicit group). The command can remove all (see UESPermissionRevoke#all) or part (see
# UESPermissionRevoke#data) of permission settings.
# 
# <tt><b>param</b></tt> entityUri UESURI of the entity for that the permission is revoked
# 
# <tt><b>param</b></tt> permission DTO containing attributes of the permission to revoke
# 
# <tt><b>throws</b></tt> UESPermissionRTException
# 
# <tt><b>since</b></tt> UES8-03
  def self.revoke(entityUri, permission = nil)
    entityUri = Ues::Core::Commons::Uri::UESURI.new(entityUri).to_java
    permission = Ues::Core::Security::Authz::UESPermissionRevoke.new(permission).to_java
    _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.security.UESPermission.java_class)
    _r = _s.revoke(entityUri, permission)
    
    return _r
  end

# This command returns a list of authorities who have permission on the specified artifact.
# 
# <tt><b>param</b></tt> entityUri UESURI of the entity where permissions are applied
# 
# <tt><b>param</b></tt> criteria DTO containing criteria for listing the permissions
# 
# <tt><b>return</b></tt> List of DTO with attributes of authorities
# 
# <tt><b>throws</b></tt> UESPermissionRTException
# 
# <tt><b>since</b></tt> UES8-03
  def self.getAuthorityList(entityUri, criteria = nil)
    entityUri = Ues::Core::Commons::Uri::UESURI.new(entityUri).to_java
    criteria = Ues::Core::Security::Authz::UESPermissionGetAuthorityList.new(criteria).to_java
    _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.security.UESPermission.java_class)
    _r = _s.getAuthorityList(entityUri, criteria)
    if (_r != nil) then _r = Ues::Platform::Commons::Lang::UESResultList.new(_r) end
    return _r
  end
  class << Ues::Core::Security::UESPermission
    alias authority_list getAuthorityList
  end

# This command returns a permission settings data for the specified artifact and authority. The permission settings is list of pairs: an
# use case code (access unit or access collection) and a cast level. The list is complete list of the all possibles actions. The result
# is composed from set actions (set by command UESPermission#grant) and from rest of actions that are defined in the system
# catalog.  
#  
# The result is streamed in JSON or CSV. 
#  
# JSON format:
# 
# 
# * key "useCaseCode" - contains codes of use cases (access units or access collections)
# 
# * key "castLevel" - contains cast level value (if it is empty, the settings for this use case is ignored)
# 
# 
# 
# CSV format:
# 
# 
# * the first column - contains codes of use cases (access units or access collections)
# 
# * the second column - contains cast level value (if it is empty, the settings for this use case is ignored)
# 
# 
# 
# Possible cast level values:
# 
# 
# * ASSISTANCE - gives access rights for executive and assistance cast roles
# 
# * EXECUTIVE - gives access rights for executive cast roles
# 
# * GUEST - gives access rights for executive, assistance and guest cast roles
# 
# * REVOKE - removes access rights
# 
# 
# 
# 
# <tt><b>param</b></tt> entityUri UESURI of the entity where permissions are applied
# 
# <tt><b>param</b></tt> options DTO containing options for getting permission settings data
# 
# <tt><b>return</b></tt> List of DTO with attributes of permission masks
# 
# <tt><b>throws</b></tt> UESPermissionRTException
# 
# <tt><b>since</b></tt> UES8-03
  def self.getAuthorityData(entityUri, options = nil)
    entityUri = Ues::Core::Commons::Uri::UESURI.new(entityUri).to_java
    options = Ues::Core::Security::Authz::UESPermissionGetAuthorityData.new(options).to_java
    _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.security.UESPermission.java_class)
    _r = _s.getAuthorityData(entityUri, options)
    if (_r != nil) then _r = Ues::Platform::Commons::Lang::UESStreamHandler.new(_r) end
    return _r
  end
  class << Ues::Core::Security::UESPermission
    alias authority_data getAuthorityData
  end

# This command returns a list of permission mask that can be granted on the specified artifact. The list of returned masks could be
# filtered by the name or code. The list is sorted by the name (and codes in case are equal) of a permission mask by default.
# 
# <tt><b>param</b></tt> artifactUri UESURI of the artifact
# 
# <tt><b>param</b></tt> criteria DTO containing criteria for listing permission masks
# 
# <tt><b>return</b></tt> List of DTO with attributes of permission masks
# 
# <tt><b>throws</b></tt> UESPermissionRTException
# 
# <tt><b>since</b></tt> UES8-03
  def self.getMaskList(artifactUri, criteria = nil)
    artifactUri = Ues::Core::Commons::Uri::UESURI.new(artifactUri).to_java
    criteria = Ues::Core::Security::Authz::UESPermissionGetMaskList.new(criteria).to_java
    _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.security.UESPermission.java_class)
    _r = _s.getMaskList(artifactUri, criteria)
    if (_r != nil) then _r = Ues::Platform::Commons::Lang::UESResultList.new(_r) end
    return _r
  end
  class << Ues::Core::Security::UESPermission
    alias mask_list getMaskList
  end

# This command returns a list of system groups that are defined for the specified artifact. The list is sorted by order in the
# configuration all time. The attributes name and description are translated to user language.
# 
# <tt><b>param</b></tt> artifactUri UESURI of the artifact
# 
# <tt><b>return</b></tt> List of DTO with attributes of system group
# 
# <tt><b>throws</b></tt> UESPermissionRTException
# 
# <tt><b>since</b></tt> UES8-03
  def self.getSystemGroupList(artifactUri, criteria = nil)
    artifactUri = Ues::Core::Commons::Uri::UESURI.new(artifactUri).to_java
    criteria = Ues::Core::Security::Authz::UESPermissionGetSystemGroupList.new(criteria).to_java
    _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.security.UESPermission.java_class)
    _r = _s.getSystemGroupList(artifactUri, criteria)
    if (_r != nil) then _r = Ues::Platform::Commons::Lang::UESResultList.new(_r) end
    return _r
  end
  class << Ues::Core::Security::UESPermission
    alias system_group_list getSystemGroupList
  end
end
